@@ -36,14 +36,21 @@
     (end-of-line)
     (delete-region start (point))))
 
-(defun elfeed-time-duration (time)
+(defun elfeed-time-duration (time &optional now)
   "Turn a time expression into a number of seconds. Uses
-`timer-duration' but allows a bit more flair."
-  (if (numberp time)
-      time
-    (when (string-match-p "[[:alpha:]]" time)
-      (let ((clean (replace-regexp-in-string "\\(ago\\|old\\|-\\)" " " time)))
-        (timer-duration clean)))))
+`timer-duration' but allows a bit more flair.
+
+If `now' is non-nil, use it as the current time (`float-time'). This
+is mostly useful for testing."
+  (cond
+   ((numberp time) time)
+   ((let ((iso-time (elfeed-parse-simple-iso-8601 time)))
+      (when iso-time (- (or now (float-time)) iso-time))))
+   ((string-match-p "[[:alpha:]]" time)
+    (let* ((clean (replace-regexp-in-string "\\(ago\\|old\\|-\\)" " " time))
+           (duration (timer-duration clean)))
+      ;; convert to float since float-time is used elsewhere
+      (when duration (float duration))))))
 
 (defun elfeed-looks-like-url-p (string)
   "Return true if STRING looks like it could be a URL."
@@ -71,21 +78,29 @@ Align should be a keyword :left or :right."
 
 (defun elfeed-cleanup (name)
   "Trim trailing and leading spaces and collapse multiple spaces."
-  (let ((trim (replace-regexp-in-string "[\n\t]+" " " (or name ""))))
+  (let ((trim (replace-regexp-in-string "[\f\n\r\t\v ]+" " " (or name ""))))
     (replace-regexp-in-string "^ +\\| +$" "" trim)))
 
 (defun elfeed-parse-simple-iso-8601 (string)
   "Attempt to parse STRING as a simply formatted ISO 8601 date.
 Examples: 2015-02-22, 2015-02, 20150222"
-  (save-match-data
-    (let ((re "^\\([0-9]\\{4\\}\\)-?\\([0-9]\\{2\\}\\)-?\\([0-9]\\{2\\}\\)?$")
-          (clean (elfeed-cleanup string)))
-      (when (string-match re clean)
-        (let ((year (string-to-number (match-string 1 clean)))
-              (month (string-to-number (match-string 2 clean)))
-              (day (string-to-number (or (match-string 3 clean) "1"))))
-          (when (and (>= year 1900) (< year 2200))
-            (float-time (encode-time 0 0 0 day month year t))))))))
+  (let* ((re (cl-flet ((re-numbers (num) (format "\\([0-9]\\{%s\\}\\)" num)))
+               (format "^%s-?%s-?%s?\\(T%s:%s:?%s?\\)?"
+                       (re-numbers 4)
+                       (re-numbers 2)
+                       (re-numbers 2)
+                       (re-numbers 2)
+                       (re-numbers 2)
+                       (re-numbers 2))))
+         (matches (save-match-data
+                    (when (string-match re string)
+                      (cl-loop for i from 1 to 7
+                               collect (let ((match (match-string i string)))
+                                         (and match (string-to-number match))))))))
+    (when matches
+      (cl-multiple-value-bind (year month day _ hour min sec) matches
+        (float-time (encode-time (or sec 0) (or min 0) (or hour 0)
+                                 (or day 1) month year t))))))
 
 (defun elfeed-new-date-for-entry (old-date new-date)
   "Decide entry date, given an existing date (nil for new) and a new date.
@@ -242,7 +257,8 @@ systems."
             (funcall interprogram-paste-function))
        (and (fboundp 'w32-get-clipboard-data)
             (funcall 'w32-get-clipboard-data))
-       (current-kill 0 :non-destructively))))
+       (ignore-errors
+         (current-kill 0 :non-destructively)))))
 
 (defun elfeed-get-link-at-point ()
   "Try to a link at point and return its URL."
