@@ -16,6 +16,7 @@
 (require 'elfeed-show)
 (require 'elfeed-search)
 
+;;;###autoload
 (defun elfeed-link-store-link ()
   "Store a link to an elfeed search or entry buffer.
 
@@ -44,6 +45,7 @@ of available props."
                             (intern (concat "elfeed-entry-" (symbol-name prop)))
                             elfeed-show-entry)))))))
 
+;;;###autoload
 (defun elfeed-link-open (filter-or-id)
   "Jump to an elfeed entry or search.
 
@@ -56,20 +58,23 @@ search buffer or show a concrete entry."
     (elfeed)
     (elfeed-search-set-filter filter-or-id)))
 
-;; Register Elfeed with Org
-(if (version< (org-version) "9.0")
-    (progn
-      (org-add-link-type "elfeed" #'elfeed-link-open)
-      (add-hook 'org-store-link-functions #'elfeed-link-store-link))
-  (with-no-warnings
-    (org-link-set-parameters
-     "elfeed"
-     :follow #'elfeed-link-open
-     :store #'elfeed-link-store-link)))
+;;;###autoload
+(eval-after-load 'org
+  `(funcall
+    ;; The extra quote below is necessary because uncompiled closures
+    ;; do not evaluate to themselves. The quote is harmless for
+    ;; byte-compiled function objects.
+    ',(lambda ()
+        (if (version< (org-version) "9.0")
+            (with-no-warnings
+              (org-add-link-type "elfeed" #'elfeed-link-open)
+              (add-hook 'org-store-link-functions #'elfeed-link-store-link))
+          (with-no-warnings
+            (org-link-set-parameters
+             "elfeed"
+             :follow #'elfeed-link-open
+             :store #'elfeed-link-store-link))))))
 
 (provide 'elfeed-link)
 
-;;;###autoload
-(eval-after-load 'org '(require 'elfeed-link))
-
 ;;; elfeed-link.el ends here
