@@ -8,6 +8,7 @@
 (require 'browse-url)
 (require 'wid-edit) ; widget-inactive face
 (require 'bookmark)
+(bookmark-maybe-load-default-file)
 
 (require 'elfeed)
 (require 'elfeed-db)
@@ -54,6 +55,13 @@ live filter editing is exited."
   :group 'elfeed
   :type '(choice function (const nil)))
 
+(defcustom elfeed-search-remain-on-entry nil
+  "When non-nil, keep point at entry after performing a command.
+
+When nil, move to next entry."
+  :group 'elfeed
+  :type 'boolean)
+
 (defcustom elfeed-search-clipboard-type 'PRIMARY
   "Selects the clipboard `elfeed-search-yank' should use.
 Choices are the symbols PRIMARY, SECONDARY, or CLIPBOARD."
@@ -396,8 +404,9 @@ The customization `elfeed-search-date-format' sets the formatting."
                         (when (elfeed-valid-regexp-p re)
                           (push re not-matches))))
                   (?# (setf limit (string-to-number (substring element 1))))
-                  (?= (let ((url (substring element 1)))
-                        (push url feeds)))
+                  (?= (let ((re (substring element 1)))
+                        (when (elfeed-valid-regexp-p re)
+                          (push re feeds))))
                   (otherwise (when (elfeed-valid-regexp-p element)
                                (push element matches)))))
     `(,@(when before
@@ -763,7 +772,8 @@ browser defined by `browse-url-generic-program'."
                     (browse-url-generic it)
                   (browse-url it)))
     (mapc #'elfeed-search-update-entry entries)
-    (unless (use-region-p) (forward-line))))
+    (unless (or elfeed-search-remain-on-entry (use-region-p))
+      (forward-line))))
 
 (defun elfeed-search-yank ()
   "Copy the selected feed items to clipboard and kill-ring."
@@ -780,7 +790,8 @@ browser defined by `browse-url-generic-program'."
           (x-set-selection elfeed-search-clipboard-type links-str)))
       (message "Copied: %s" links-str)
       (mapc #'elfeed-search-update-entry entries)
-      (unless (use-region-p) (forward-line)))))
+      (unless (or elfeed-search-remain-on-entry (use-region-p))
+        (forward-line)))))
 
 (defun elfeed-search-tag-all (tag)
   "Apply TAG to all selected entries."
@@ -788,7 +799,8 @@ browser defined by `browse-url-generic-program'."
   (let ((entries (elfeed-search-selected)))
     (elfeed-tag entries tag)
     (mapc #'elfeed-search-update-entry entries)
-    (unless (use-region-p) (forward-line))))
+    (unless (or elfeed-search-remain-on-entry (use-region-p))
+      (forward-line))))
 
 (defun elfeed-search-untag-all (tag)
   "Remove TAG from all selected entries."
@@ -796,7 +808,8 @@ browser defined by `browse-url-generic-program'."
   (let ((entries (elfeed-search-selected)))
     (elfeed-untag entries tag)
     (mapc #'elfeed-search-update-entry entries)
-    (unless (use-region-p) (forward-line))))
+    (unless (or elfeed-search-remain-on-entry (use-region-p))
+      (forward-line))))
 
 (defun elfeed-search-toggle-all (tag)
   "Toggle TAG on all selected entries."
@@ -809,7 +822,8 @@ browser defined by `browse-url-generic-program'."
     (elfeed-tag entries-tag tag)
     (elfeed-untag entries-untag tag)
     (mapc #'elfeed-search-update-entry entries)
-    (unless (use-region-p) (forward-line))))
+    (unless (or elfeed-search-remain-on-entry (use-region-p))
+      (forward-line))))
 
 (defun elfeed-search-show-entry (entry)
   "Display the currently selected item in a buffer."
@@ -818,7 +832,7 @@ browser defined by `browse-url-generic-program'."
   (when (elfeed-entry-p entry)
     (elfeed-untag entry 'unread)
     (elfeed-search-update-entry entry)
-    (forward-line)
+    (unless elfeed-search-remain-on-entry (forward-line))
     (elfeed-show-entry entry)))
 
 (defun elfeed-search-set-entry-title (title)
